@@ -425,8 +425,8 @@ class _SignedPoster:
             if not (key in self.required or key in self.optional):
                 raise TypeError("SignedPoster got unexpected keyword argument '" + key + "'")
             kwset.add(key)
-            if key == "db_id":
-                kwdict["db/id"] = value
+            if key == "db_id" or key == "ledger_id":
+                kwdict["ledger/id"] = value
             else:
                 kwdict[key] = value
         for reqkey in self.required:
@@ -437,9 +437,16 @@ class _SignedPoster:
         if not self.unsigned:
             body, headers, _ = self.signer.sign_query(kwdict)
         rval = await self._post_body_with_headers(body, headers)
-        # If this is a new-db, we need to await till it comes into existance.
-        if isinstance(rval, str) and len(rval) == 64 and self.url.split("/")[-1] == "new-db" and "db_id" in kwargs:
-            dbid = kwargs["db_id"]
+        # If this is a new-db or new-legger, we need to await till it comes into existance.
+        if (isinstance(rval, str) and len(rval) == 64 and
+                (
+                    (self.url.split("/")[-1] == "new-db" and "db_id" in kwargs) or
+                    (self.url.split("/")[-1] == "new-ledger" and "ledger_id" in kwargs)
+                )):
+            if "ledger_id" in kwargs:
+                dbid = kwargs["ledger_id"]
+            else:
+                dbid = kwargs["db_id"]
             while True:
                 databases = await self.client.ledgers()
                 for database in databases:
@@ -452,7 +459,7 @@ class _SignedPoster:
 
 class _Network:
     """Helper class for square bracket interface to Fluree Client"""
-    def __init__(self, flureeclient, netname, options):
+    def __init__(self, flureeclient, netname, options, debug):
         """Constructor
 
         Parameters
@@ -467,6 +474,7 @@ class _Network:
         self.client = flureeclient
         self.netname = netname
         self.options = options
+        self.debug = debug
 
     def __str__(self):
         """Cast to string
@@ -499,7 +507,7 @@ class _Network:
         database = self.netname + "/" + key
         if key not in self.options:
             raise KeyError("No such database: '" + database + "'")
-        return _DbFunctor(self.client, database)
+        return _DbFunctor(self.client, database, self.debug)
 
     def __iter__(self):
         """Iterate over databases in network
@@ -513,12 +521,12 @@ class _Network:
         """
         for key in self.options:
             database = self.netname + "/" + key
-            yield _DbFunctor(self.client, database)
+            yield _DbFunctor(self.client, database, self.debug)
 
 
 class _DbFunctor:
     """Helper functor class for square bracket interface to Fluree Client"""
-    def __init__(self, client, database):
+    def __init__(self, client, database, debug):
         """Constructor
 
         Parameters
@@ -530,6 +538,7 @@ class _DbFunctor:
         """
         self.client = client
         self.database = database
+        self.debug = debug
 
     def __str__(self):
         """Cast to string
@@ -565,7 +574,8 @@ class _DbFunctor:
                                self.client.https,
                                self.client.ssl_verify,
                                sig_validity,
-                               sig_fuel)
+                               sig_fuel,
+                               debug=self.debug)
 
 
 class FlureeClient:
@@ -638,9 +648,9 @@ class FlureeClient:
         self.use_get = set(["health", "new_keys", "nw_state", "version"])
         self.required = {}
         self.required["new_db"] = set(["db_id"])
-        self.required["new_ledger"] = set(["db_id"])
+        self.required["new_ledger"] = set(["ledger_id"])
         self.required["delete_db"] = set(["db_id"])
-        self.required["delete_ledger"] = set(["db_id"])
+        self.required["delete_ledger"] = set(["ledger_id"])
         self.required["add_server"] = set(["server"])
         self.required["delete_server"] = set(["server"])
         self.optional = {"new_db": set(["snapshot"])}
@@ -742,7 +752,7 @@ class FlureeClient:
         if use_get:
             if api_endpoint == "health":
                 return _UnsignedGetter(self.session, url, self.ssl_verify_disabled, ready="ready", debug=self.debug)
-            return _UnsignedGetter(self.session, url, self.ssl_verify_disabled, debug=self.debug, debug=self.debug)
+            return _UnsignedGetter(self.session, url, self.ssl_verify_disabled, debug=self.debug)
         return _SignedPoster(self, self.session, self.signer, url, required, optional, self.ssl_verify_disabled, unsigned=True, debug=self.debug)
 
     async def __getitem__(self, key):
@@ -775,7 +785,7 @@ class FlureeClient:
                 options.add(pair[1])
         if not bool(options):
             raise KeyError("No such network: '" + key + "'")
-        network = _Network(self, key, options)
+        network = _Network(self, key, options, self.debug)
         if subkey is None:
             return network
         return network[subkey]
@@ -799,7 +809,7 @@ class FlureeClient:
                 optionsmap[network] = set()
             optionsmap[network].add(database)
         for key, item in optionsmap.items():
-            yield _Network(self, key, item)
+            yield _Network(self, key, item, self.debug)
 
     async def close_session(self):
         """Close HTTP(S) session to FlureeDB"""
@@ -818,7 +828,8 @@ class _FlureeDbClient:
                  https=False,
                  ssl_verify=True,
                  sig_validity=120,
-                 sig_fuel=1000):
+                 sig_fuel=1000,
+                 debug=False):
         """Constructor
 
         Parameters
@@ -845,6 +856,7 @@ class _FlureeDbClient:
         self.host = host
         self.port = port
         self.https = https
+        self.debug = debug
         self.ssl_verify_disabled = False
         self.monitor = {}
         self.monitor["listeners"] = {}
@@ -1619,6 +1631,7 @@ class _FlureeDbClient:
         FlureeKeyRequired
             When 'command' endpoint is invoked in open-API mode.
         """
+        debug = self.debug
         class _StringEndpoint:
             def __init__(self, api_endpoint, client, ssl_verify_disabled=False):
                 """Constructor
@@ -1670,16 +1683,23 @@ class _FlureeDbClient:
                 FlureeHttpError
                     When HTTP status from fluree server is anything other than 200
                 """
+                if debug:
+                    print("_post_body_with_headers", self.url, self.ssl_verify_disabled)
+                    print("  headers:", headers)
+                    print("  body:", body)
                 if self.ssl_verify_disabled:
                     async with self.session.post(self.url, data=body, headers=headers, ssl=False) as resp:
                         if resp.status != 200:
                             raise FlureeHttpError(await resp.text(), resp.status)
-                        return await resp.text()
+                        rval = await resp.text()
                 else:
                     async with self.session.post(self.url, data=body, headers=headers) as resp:
                         if resp.status != 200:
                             raise FlureeHttpError(await resp.text(), resp.status)
-                        return await resp.text()
+                        rval = await resp.text()
+                if debug:
+                    print("rval:", rval)
+                return rval
 
             async def header_signed(self, query_body, contenttype="application/json"):
                 """Do a HTTP query using headers for signing
